python_rest_api_client
======================

A sample Python client for communicating with the UltraDNS REST API

Dependencies and Installation
========================

This sample code depends on the requests library, which can be found at: http://docs.python-requests.org/en/latest/

If you have pip installed, you can add the client and requests to your environment with:

```
pip install ultra_rest_client
```

Functionality
=============

The sample code does not attempt to implement a client for all available UltraDNS REST API functionality.  It provides access to basic functionality.  Adding additional functionality should be relatively straightforward, and any contributions from the UltraDNS community would be greatly appreciated.  See sample.py for an example of how to use this library in your own code.

Questions
=========

Please contact UltraDNS support if you have any questions or encounter any issues with this code.

